#include "compute_atom_molecule.h"
#include "compute_bond_local.h"
#include "compute_centro_atom.h"
#include "compute_cluster_atom.h"
#include "compute_cna_atom.h"
#include "compute_com.h"
#include "compute_com_molecule.h"
#include "compute_contact_atom.h"
#include "compute_coord_atom.h"
#include "compute_displace_atom.h"
#include "compute_erotate_multisphere.h"
#include "compute_erotate_sphere_atom.h"
#include "compute_erotate_sphere.h"
#include "compute_group_group.h"
#include "compute_gyration.h"
#include "compute_gyration_molecule.h"
#include "compute_inertia_molecule.h"
#include "compute_ke_atom.h"
#include "compute_ke.h"
#include "compute_ke_multisphere.h"
#include "compute_msd.h"
#include "compute_msd_molecule.h"
#include "compute_nparticles_tracer_region.h"
#include "compute_pair_gran_local.h"
#include "compute_pe_atom.h"
#include "compute_pe.h"
#include "compute_pressure.h"
#include "compute_property_atom.h"
#include "compute_property_local.h"
#include "compute_property_molecule.h"
#include "compute_rdf.h"
#include "compute_reduce.h"
#include "compute_reduce_region.h"
#include "compute_rigid.h"
#include "compute_slice.h"
#include "compute_stress_atom.h"
#include "compute_surface.h"
#include "compute_temp.h"
